@@ -14,6 +14,8 @@ import copy
 
 from oslo_config import cfg
 
+from oslo_log import versionutils
+
 _DEFAULT_LOG_DATE_FORMAT = "%Y-%m-%d %H:%M:%S"
 
 
@@ -22,12 +24,13 @@ common_cli_opts = [
                 short='d',
                 default=False,
                 help='Print debugging output (set logging level to '
-                     'DEBUG instead of default WARNING level).'),
+                     'DEBUG instead of default INFO level).'),
     cfg.BoolOpt('verbose',
                 short='v',
-                default=False,
-                help='Print more verbose output (set logging level to '
-                     'INFO instead of default WARNING level).'),
+                default=True,
+                help='If set to false, will disable INFO logging level, '
+                     'making WARNING the default.',
+                deprecated_for_removal=True),
 ]
 
 logging_cli_opts = [
@@ -63,17 +66,16 @@ logging_cli_opts = [
     cfg.BoolOpt('use-syslog',
                 default=False,
                 help='Use syslog for logging. '
-                     'Existing syslog format is DEPRECATED during I, '
-                     'and will change in J to honor RFC5424.'),
+                     'Existing syslog format is DEPRECATED '
+                     'and will be changed later to honor RFC5424.'),
     cfg.BoolOpt('use-syslog-rfc-format',
-                # TODO(bogdando) remove or use True after existing
-                #    syslog format deprecation in J
-                default=False,
+                default=True,
+                deprecated_for_removal=True,
                 help='(Optional) Enables or disables syslog rfc5424 format '
                      'for logging. If enabled, prefixes the MSG part of the '
                      'syslog message with APP-NAME (RFC5424). The '
-                     'format without the APP-NAME is deprecated in I, '
-                     'and will be removed in J.'),
+                     'format without the APP-NAME is deprecated in Kilo, '
+                     'and will be removed in Mitaka, along with this option.'),
     cfg.StrOpt('syslog-log-facility',
                default='LOG_USER',
                help='Syslog facility to receive log lines.')
@@ -93,7 +95,7 @@ DEFAULT_LOG_LEVELS = ['amqp=WARN', 'amqplib=WARN', 'boto=WARN',
                       'requests.packages.urllib3.util.retry=WARN',
                       'urllib3.util.retry=WARN',
                       "keystonemiddleware=WARN", "routes.middleware=WARN",
-                      "stevedore=WARN"]
+                      "stevedore=WARN", "taskflow=WARN"]
 
 log_opts = [
     cfg.StrOpt('logging_context_format_string',
@@ -109,7 +111,7 @@ log_opts = [
                default='%(funcName)s %(pathname)s:%(lineno)d',
                help='Data to append to log format when level is DEBUG.'),
     cfg.StrOpt('logging_exception_prefix',
-               default='%(asctime)s.%(msecs)03d %(process)d TRACE %(name)s '
+               default='%(asctime)s.%(msecs)03d %(process)d ERROR %(name)s '
                '%(instance)s',
                help='Prefix each line of exception output with this format.'),
     cfg.ListOpt('default_log_levels',
@@ -118,9 +120,6 @@ log_opts = [
     cfg.BoolOpt('publish_errors',
                 default=False,
                 help='Enables or disables publication of error events.'),
-    cfg.BoolOpt('fatal_deprecations',
-                default=False,
-                help='Enables or disables fatal status of deprecations.'),
 
     # NOTE(mikal): there are two options here because sometimes we are handed
     # a full instance (and could include more information), and other times we
@@ -153,4 +152,5 @@ def list_opts():
     :returns: a list of (group_name, opts) tuples
     """
     return [(None, copy.deepcopy(common_cli_opts + logging_cli_opts +
-                                 generic_log_opts + log_opts))]
+                                 generic_log_opts + log_opts +
+                                 versionutils.deprecated_opts))]
