@@ -17,6 +17,10 @@
 import logging
 import os
 import sys
+try:
+    import syslog
+except ImportError:
+    syslog = None
 import tempfile
 
 import mock
@@ -28,6 +32,7 @@ from oslo_i18n import fixture as fixture_trans
 from oslo_serialization import jsonutils
 from oslotest import base as test_base
 import six
+import testtools
 
 from oslo_log import _options
 from oslo_log import formatters
@@ -210,29 +215,64 @@ class SysLogHandlersTestCase(BaseTestCase):
                          expected.getMessage())
 
 
+@testtools.skipUnless(syslog, "syslog is not available")
+class OSSysLogHandlerTestCase(BaseTestCase):
+    def tests_handler(self):
+        handler = handlers.OSSysLogHandler()
+        syslog.syslog = mock.Mock()
+        handler.emit(
+            logging.LogRecord("foo", logging.INFO,
+                              "path", 123, "hey!",
+                              None, None))
+        self.assertTrue(syslog.syslog.called)
+
+    def test_find_facility(self):
+        self.assertEqual(syslog.LOG_USER, log._find_facility("user"))
+        self.assertEqual(syslog.LOG_LPR, log._find_facility("LPR"))
+        self.assertEqual(syslog.LOG_LOCAL3, log._find_facility("log_local3"))
+        self.assertEqual(syslog.LOG_UUCP, log._find_facility("LOG_UUCP"))
+        self.assertRaises(TypeError,
+                          log._find_facility,
+                          "fougere")
+
+
 class LogLevelTestCase(BaseTestCase):
     def setUp(self):
         super(LogLevelTestCase, self).setUp()
         levels = self.CONF.default_log_levels
         levels.append("nova-test=INFO")
         levels.append("nova-not-debug=WARN")
+        levels.append("nova-below-debug=7")
+        levels.append("nova-trace=TRACE")
         self.config(default_log_levels=levels,
                     verbose=True)
         log.setup(self.CONF, 'testing')
         self.log = log.getLogger('nova-test')
         self.log_no_debug = log.getLogger('nova-not-debug')
+        self.log_below_debug = log.getLogger('nova-below-debug')
+        self.log_trace = log.getLogger('nova-trace')
 
     def test_is_enabled_for(self):
         self.assertTrue(self.log.isEnabledFor(logging.INFO))
         self.assertFalse(self.log_no_debug.isEnabledFor(logging.DEBUG))
+        self.assertTrue(self.log_below_debug.isEnabledFor(logging.DEBUG))
+        self.assertTrue(self.log_below_debug.isEnabledFor(7))
+        self.assertTrue(self.log_trace.isEnabledFor(log.TRACE))
 
     def test_has_level_from_flags(self):
         self.assertEqual(logging.INFO, self.log.logger.getEffectiveLevel())
 
+    def test_has_level_from_flags_for_trace(self):
+        self.assertEqual(log.TRACE, self.log_trace.logger.getEffectiveLevel())
+
     def test_child_log_has_level_of_parent_flag(self):
         l = log.getLogger('nova-test.foo')
         self.assertEqual(logging.INFO, l.logger.getEffectiveLevel())
 
+    def test_child_log_has_level_of_parent_flag_for_trace(self):
+        l = log.getLogger('nova-trace.foo')
+        self.assertEqual(log.TRACE, l.logger.getEffectiveLevel())
+
 
 class JSONFormatterTestCase(LogTestBase):
     def setUp(self):
@@ -516,6 +556,20 @@ class InstanceRecordTestCase(LogTestBase):
         self.assertEqual(infoexpected, self.stream.getvalue())
 
 
+class TraceLevelTestCase(LogTestBase):
+    def setUp(self):
+        super(TraceLevelTestCase, self).setUp()
+        self.config(logging_context_format_string="%(message)s")
+        self.mylog = log.getLogger()
+        self._add_handler_with_cleanup(self.mylog)
+        self._set_log_level_with_cleanup(self.mylog, log.TRACE)
+
+    def test_trace_log_msg(self):
+        ctxt = _fake_context()
+        self.mylog.trace("my trace message", context=ctxt)
+        self.assertEqual('my trace message\n', self.stream.getvalue())
+
+
 class DomainTestCase(LogTestBase):
     def setUp(self):
         super(DomainTestCase, self).setUp()
@@ -563,6 +617,7 @@ class SetDefaultsTestCase(BaseTestCase):
         super(SetDefaultsTestCase, self).setUp()
         self.conf = self.TestConfigOpts()
         self.conf.register_opts(_options.log_opts)
+        self.conf.register_cli_opts(_options.logging_cli_opts)
 
         self._orig_defaults = dict([(o.dest, o.default)
                                     for o in _options.log_opts])
@@ -593,6 +648,17 @@ class SetDefaultsTestCase(BaseTestCase):
         self.assertEqual(['foo=bar'], self.conf.default_log_levels)
         self.assertIsNotNone(self.conf.logging_context_format_string)
 
+    def test_tempest_set_log_file(self):
+        log.tempest_set_log_file('foo.log')
+        log.set_defaults()
+        self.conf([])
+        self.assertEqual('foo.log', self.conf.log_file)
+
+    def test_log_file_defaults_to_none(self):
+        log.set_defaults()
+        self.conf([])
+        self.assertEqual(None, self.conf.log_file)
+
 
 class LogConfigOptsTestCase(BaseTestCase):
 
@@ -626,7 +692,7 @@ class LogConfigOptsTestCase(BaseTestCase):
                          _options._DEFAULT_LOG_DATE_FORMAT)
 
         self.assertEqual(self.CONF.use_syslog, False)
-        self.assertEqual(self.CONF.use_syslog_rfc_format, False)
+        self.assertEqual(self.CONF.use_syslog_rfc_format, True)
 
     def test_log_file(self):
         log_file = '/some/path/foo-bar.log'
@@ -643,6 +709,24 @@ class LogConfigOptsTestCase(BaseTestCase):
         self.assertIsInstance(logger.handlers[0],
                               logging.handlers.WatchedFileHandler)
 
+    def test_log_publish_errors_handlers(self):
+        fake_handler = mock.MagicMock()
+        with mock.patch('oslo_utils.importutils.import_object',
+                        return_value=fake_handler) as mock_import:
+            log_dir = tempfile.mkdtemp()
+            self.CONF(['--log-dir', log_dir])
+            self.CONF.set_default('use_stderr', False)
+            self.CONF.set_default('publish_errors', True)
+            log._setup_logging_from_conf(self.CONF, 'test', 'test')
+            logger = log._loggers[None].logger
+            self.assertEqual(2, len(logger.handlers))
+            self.assertIsInstance(logger.handlers[0],
+                                  logging.handlers.WatchedFileHandler)
+            self.assertEqual(logger.handlers[1], fake_handler)
+            mock_import.assert_called_once_with(
+                'oslo_messaging.notify.log_handler.PublishErrorsHandler',
+                logging.ERROR)
+
     def test_logfile_deprecated(self):
         logfile = '/some/other/path/foo-bar.log'
         self.CONF(['--logfile', logfile])
@@ -776,8 +860,7 @@ class KeywordArgumentAdapterTestCase(BaseTestCase):
                        'extra_keys': ['anything', 'context',
                                       'instance', 'resource_uuid'],
                        'instance': 'instance identifier',
-                       'resource_uuid': 'UUID for instance',
-                       'anything': 'goes'}},
+                       'resource_uuid': 'UUID for instance'}},
         )
 
     def test_pass_args_to_log(self):
@@ -823,3 +906,37 @@ class KeywordArgumentAdapterTestCase(BaseTestCase):
                        'extra_keys': ['name']},
                 exc_info='exception',
             )
+
+
+class UnicodeConversionTestCase(BaseTestCase):
+
+    def test_ascii_to_unicode(self):
+        msg = u'Message with unicode char \ua000 in the middle'
+        enc_msg = msg.encode('utf-8')
+        result = log._ensure_unicode(enc_msg)
+        self.assertEqual(msg, result)
+        self.assertIsInstance(result, six.text_type)
+
+    def test_unicode_to_unicode(self):
+        msg = u'Message with unicode char \ua000 in the middle'
+        result = log._ensure_unicode(msg)
+        self.assertEqual(msg, result)
+        self.assertIsInstance(result, six.text_type)
+
+    def test_exception_to_unicode(self):
+        msg = u'Message with unicode char \ua000 in the middle'
+        exc = Exception(msg)
+        result = log._ensure_unicode(exc)
+        self.assertEqual(msg, result)
+        self.assertIsInstance(result, six.text_type)
+
+
+class LoggerNameTestCase(LoggerTestCase):
+
+    def test_oslo_dot(self):
+        l = log.getLogger('oslo.subname')
+        self.assertEqual(l.logger.name, 'oslo.subname')
+
+    def test_oslo_underscore(self):
+        l = log.getLogger('oslo_subname')
+        self.assertEqual(l.logger.name, 'oslo.subname')
